@@ -45,7 +45,9 @@ class Network3Medusa():
                 self.send_webex_notification()
         
     def py2output(self):
-        self.output = subprocess.run(["python", "call_clid.py", self.command], capture_output=True)
+        print("calling python2")
+        self.output = subprocess.run(["python", "call_cli.py", self.command], capture_output=True)
+        print(self.output)
 
     def add_file_to_hedera(self, raw_json):
         self.client = Client.forTestnet()
